Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2319)

Unified Diff: content/public/browser/resource_dispatcher_host_delegate.h

Issue 2484633004: Change Lo-Fi bool to bitmask to support multiple Previews types (Closed)
Patch Set: fix ContentResourceProviderTest Created 3 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/common/resource_request.h ('k') | content/public/browser/resource_dispatcher_host_delegate.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/public/browser/resource_dispatcher_host_delegate.h
diff --git a/content/public/browser/resource_dispatcher_host_delegate.h b/content/public/browser/resource_dispatcher_host_delegate.h
index 875b822d3c4436346b5876ae94778c51b16b2107..c3c969916bedd2ddb1862ee237a7dc6bc432f538 100644
--- a/content/public/browser/resource_dispatcher_host_delegate.h
+++ b/content/public/browser/resource_dispatcher_host_delegate.h
@@ -13,6 +13,7 @@
#include "base/time/time.h"
#include "content/common/content_export.h"
#include "content/public/browser/resource_request_info.h"
+#include "content/public/common/previews_state.h"
#include "content/public/common/resource_type.h"
#include "ui/base/page_transition_types.h"
@@ -122,10 +123,13 @@ class CONTENT_EXPORT ResourceDispatcherHostDelegate {
// TODO(maksims): Remove this once all the callers are modified.
virtual void RequestComplete(net::URLRequest* url_request);
- // Asks the embedder if Lo-Fi mode should be enabled for the given request. It
- // is only called for requests with an unspecified Lo-Fi value.
- virtual bool ShouldEnableLoFiMode(const net::URLRequest& url_request,
- content::ResourceContext* resource_context);
+ // Asks the embedder for the PreviewsState which says which previews should
+ // be enabled for the given request. The PreviewsState is a bitmask of
+ // potentially several Previews optimizations. It is only called for requests
+ // with an unspecified Previews state.
+ virtual PreviewsState GetPreviewsState(
+ const net::URLRequest& url_request,
+ content::ResourceContext* resource_context);
// Asks the embedder for NavigationData related to this request. It is only
// called for navigation requests.
« no previous file with comments | « content/common/resource_request.h ('k') | content/public/browser/resource_dispatcher_host_delegate.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698